@@ -4,6 +4,14 @@
 
 #include <orc/orcprogram.h>
 
+ORC_BEGIN_DECLS
+
+typedef enum {
+  ORC_TARGET_POWERPC_64BIT = (1<<0)
+} OrcTargetPowerPCFlags;
+
+#ifdef ORC_ENABLE_UNSTABLE_API
+
 enum {
   POWERPC_R0 = ORC_GP_REG_BASE,
   POWERPC_R1,
@@ -82,6 +90,9 @@ void powerpc_emit_addi (OrcCompiler *compiler, int regd, int rega, int imm);
 void powerpc_emit_lwz (OrcCompiler *compiler, int regd, int rega, int imm);
 void powerpc_emit_stw (OrcCompiler *compiler, int regs, int rega, int offset);
 void powerpc_emit_stwu (OrcCompiler *compiler, int regs, int rega, int offset);
+void powerpc_emit_ld (OrcCompiler *compiler, int regd, int rega, int imm);
+void powerpc_emit_std (OrcCompiler *compiler, int regs, int rega, int offset);
+void powerpc_emit_stdu (OrcCompiler *compiler, int regs, int rega, int offset);
 
 void powerpc_emit_ret (OrcCompiler *compiler);
 void powerpc_emit_b (OrcCompiler *compiler, int label);
@@ -90,39 +101,29 @@ void powerpc_emit_bne (OrcCompiler *compiler, int label);
 void powerpc_emit_label (OrcCompiler *compiler, int label);
 void powerpc_add_fixup (OrcCompiler *compiler, int type, unsigned char *ptr, int label);
 void powerpc_do_fixups (OrcCompiler *compiler);
-void orc_powerpc_flush_cache (OrcCode *code);
+ORC_API void orc_powerpc_flush_cache (OrcCode *code);
 
-void powerpc_emit_srawi (OrcCompiler *compiler, int regd, int rega, int shift,
-    int record);
-void powerpc_emit_655510 (OrcCompiler *compiler, int major, int d, int a,
-    int b, int minor);
-void powerpc_emit_D (OrcCompiler *compiler, const char *name,
-    unsigned int insn, int regd, int rega, int imm);
-void powerpc_emit_X (OrcCompiler *compiler, unsigned int insn, int d, int a,
-    int b);
-void powerpc_emit_VA (OrcCompiler *compiler, const char *name, unsigned int insn, int d, int a, int b,
-    int c);
-void powerpc_emit_VA_acb (OrcCompiler *compiler, const char *name, unsigned int insn, int d, int a, int b,
-    int c);
-void powerpc_emit_VX (OrcCompiler *compiler, unsigned int insn, int d, int a,
-    int b);
+void powerpc_emit_srawi (OrcCompiler *compiler, int regd, int rega, int shift, int record);
+void powerpc_emit_655510 (OrcCompiler *compiler, int major, int d, int a, int b, int minor);
+void powerpc_emit_D (OrcCompiler *compiler, const char *name, unsigned int insn, int regd, int rega, int imm);
+void powerpc_emit_X (OrcCompiler *compiler, unsigned int insn, int d, int a, int b);
+void powerpc_emit_VA (OrcCompiler *compiler, const char *name, unsigned int insn, int d, int a, int b, int c);
+void powerpc_emit_VA_acb (OrcCompiler *compiler, const char *name, unsigned int insn, int d, int a, int b, int c);
+void powerpc_emit_VX (OrcCompiler *compiler, unsigned int insn, int d, int a, int b);
 void powerpc_emit_VX_b (OrcCompiler *p, const char *name, unsigned int insn, int a);
 void powerpc_emit_VX_db (OrcCompiler *p, const char *name, unsigned int insn, int d, int b);
 void powerpc_emit_VX_dbi (OrcCompiler *p, const char *name, unsigned int insn, int d, int b, int imm);
-void powerpc_emit_VXR (OrcCompiler *compiler, const char *name,
-    unsigned int insn, int d, int a, int b, int record);
-void powerpc_emit_VX_2 (OrcCompiler *p, const char *name, unsigned int insn,
-    int d, int a, int b);
-void powerpc_emit_VX_3 (OrcCompiler *p, const char *name, unsigned int insn,
-    int d, int a, int b, int c);
-void powerpc_emit_VX_3_reg (OrcCompiler *p, const char *name, unsigned int insn,
-    int d, int a, int b, int c);
-void powerpc_emit_VX_4 (OrcCompiler *p, const char *name, unsigned int insn,
-    int d, int a);
-int powerpc_get_constant (OrcCompiler *p, int type, int value);
-int powerpc_get_constant_full (OrcCompiler *p, int value0, int value1, int value2, int value3);
+void powerpc_emit_VXR (OrcCompiler *compiler, const char *name, unsigned int insn, int d, int a, int b, int record);
+void powerpc_emit_VX_2 (OrcCompiler *p, const char *name, unsigned int insn, int d, int a, int b);
+void powerpc_emit_VX_3 (OrcCompiler *p, const char *name, unsigned int insn, int d, int a, int b, int c);
+void powerpc_emit_VX_3_reg (OrcCompiler *p, const char *name, unsigned int insn, int d, int a, int b, int c);
+void powerpc_emit_VX_4 (OrcCompiler *p, const char *name, unsigned int insn, int d, int a);
+int  powerpc_get_constant (OrcCompiler *p, int type, int value);
+int  powerpc_get_constant_full (OrcCompiler *p, int value0, int value1, int value2, int value3);
+void powerpc_load_long_constant (OrcCompiler *p, int reg, orc_uint32 a, orc_uint32 b, orc_uint32 c, orc_uint32 d);
 
 /* instructions */
+#define powerpc_emit_vand(p,a,b,c)         powerpc_emit_VX_2 (p, "vand", 0x10000404, a, b, c)
 #define powerpc_emit_vandc(p,a,b,c)        powerpc_emit_VX_2 (p, "vandc", 0x10000444, a, b, c)
 
 #define powerpc_emit_vor(p,a,b,c)          powerpc_emit_VX_2 (p, "vor", 0x10000484, a, b, c)
@@ -168,6 +169,9 @@ int powerpc_get_constant_full (OrcCompiler *p, int value0, int value1, int value
 
 #define powerpc_emit_vperm(p,a,b,c,d)      powerpc_emit_VA (p, "vperm", 0x1000002b, a, b, c, d)
 
+#endif
+
+ORC_END_DECLS
 
 #endif
 
