@@ -39,7 +39,6 @@ typedef struct _OrcConstant OrcConstant;
 /* typedef struct _OrcFixup OrcFixup; */
 typedef struct _OrcTarget OrcTarget;
 typedef struct _OrcCode OrcCode;
-/* typedef struct _OrcCodeChunk OrcCodeChunk; */
 
 typedef enum {
   ORC_COMPILE_RESULT_OK = 0,
@@ -53,10 +52,11 @@ typedef enum {
 
 } OrcCompileResult;
 
+#include <stddef.h>
 
 #ifndef _ORC_INTEGER_TYPEDEFS_
 #define _ORC_INTEGER_TYPEDEFS_
-#if defined(__STDC__) && __STDC__ && __STDC_VERSION__ >= 199901L
+#if defined(__STDC__) && defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
 #include <stdint.h>
 typedef int8_t orc_int8;
 typedef int16_t orc_int16;
@@ -122,8 +122,14 @@ typedef unsigned int orc_bool;
 
 #define ORC_PTR_TO_INT(x) ((int)(orc_intptr)(x))
 #define ORC_PTR_OFFSET(ptr,offset) ((void *)(((unsigned char *)(ptr)) + (offset)))
-#define ORC_STRUCT_OFFSET(struct_type, member)    \
-      (ORC_PTR_TO_INT((unsigned char *) &((struct_type*) 0)->member))
+
+#if (defined(__GNUC__)  && __GNUC__ >= 4) || defined (_MSC_VER)
+#define ORC_STRUCT_OFFSET(struct_type, member) \
+      ((int) offsetof (struct_type, member))
+#else
+#define ORC_STRUCT_OFFSET(struct_type, member)	\
+      ((int) ((unsigned char **) &((struct_type*) 0)->member))
+#endif
 
 #ifdef ORC_ENABLE_UNSTABLE_API
 
@@ -139,11 +145,10 @@ typedef unsigned int orc_bool;
 #endif
 
 #define ORC_READ_UINT32_LE(ptr) \
-  ((orc_uint32)( \
-    ((orc_uint8 *)(ptr))[0] | \
-    (((orc_uint8 *)(ptr))[1]<<8) | \
-    (((orc_uint8 *)(ptr))[2]<<16) | \
-    (((orc_uint8 *)(ptr))[3]<<24)))
+  (((orc_uint32)((orc_uint8 *)(ptr))[0]) | \
+   ((orc_uint32)(((orc_uint8 *)(ptr))[1])<<8) | \
+   ((orc_uint32)(((orc_uint8 *)(ptr))[2])<<16) | \
+   ((orc_uint32)(((orc_uint8 *)(ptr))[3])<<24))
 
 #define ORC_WRITE_UINT32_LE(ptr,val) \
   do { \
@@ -194,31 +199,39 @@ typedef unsigned int orc_bool;
 #define ORC_END_DECLS
 #endif
 
-#ifdef _MSC_VER
-#ifdef ORC_EXPORTS
-#define ORC_EXPORT __declspec(dllexport) extern
+/* FIXME: unused, remove */
+#define ORC_EXPORT
+
+#if (defined(_MSC_VER) || defined(_WIN32)) && !defined(ORC_STATIC_COMPILATION)
+#define ORC_API_IMPORT __declspec(dllimport) extern
 #else
-#define ORC_EXPORT __declspec(dllimport) extern
+#define ORC_API_IMPORT extern
 #endif
-#else /* not _MSC_VER */
-#define ORC_EXPORT extern
+
+#ifdef BUILDING_ORC
+#define ORC_API ORC_API_EXPORT /* defined in config.h */
+#else
+#define ORC_API ORC_API_IMPORT
 #endif
 
 ORC_BEGIN_DECLS
 
 #ifdef ORC_ENABLE_UNSTABLE_API
 
-int get_file_int (const char *file, int *value);
-char * get_file (const char *file);
-char * get_cpuinfo_line (char *cpuinfo, const char *tag);
+/* FIXME: remove, these are internal functions that were never exported */
+#if defined(__arm__) || defined(__mips__)
+char * get_proc_cpuinfo (void);
+#endif
+
 char * _strndup (const char *s, int n);
 char ** strsplit (const char *s, char delimiter);
 char * get_tag_value (char *s, const char *tag);
 
 orc_int64 _strtoll (const char *nptr, char **endptr, int base);
 
-void orc_global_mutex_lock (void);
-void orc_global_mutex_unlock (void);
+/* FIXME: why are these exported ? */
+ORC_API void orc_global_mutex_lock (void);
+ORC_API void orc_global_mutex_unlock (void);
 
 #endif
 
